@@ -7,13 +7,13 @@
 #include "dbushelper.h"
 #include "core_debug.h"
 
-#include <QRegExp>
-#include <QProcess>
-#include <QDebug>
-#include <QUrl>
-#include <QFile>
 #include <QCoreApplication>
+#include <QDebug>
+#include <QFile>
+#include <QProcess>
+#include <QRegularExpression>
 #include <QStandardPaths>
+#include <QUrl>
 
 #include "kdeconnectconfig.h"
 
@@ -22,8 +22,8 @@
 #include <QRegularExpressionMatch>
 #endif
 
-namespace DBusHelper {
-
+namespace DBusHelper
+{
 #ifdef Q_OS_MAC
 class DBusInstancePrivate
 {
@@ -33,6 +33,7 @@ public:
 
     void launchDBusDaemon();
     void closeDBusDaemon();
+
 private:
     QProcess *m_dbusProcess;
 };
@@ -40,10 +41,10 @@ private:
 static DBusInstancePrivate dbusInstance;
 #endif
 
-void filterNonExportableCharacters(QString& s)
+void filterNonExportableCharacters(QString &s)
 {
-    static QRegExp regexp(QStringLiteral("[^A-Za-z0-9_]"), Qt::CaseSensitive, QRegExp::Wildcard);
-    s.replace(regexp,QLatin1String("_"));
+    static QRegularExpression regexp(QStringLiteral("[^A-Za-z0-9_]"), QRegularExpression::CaseInsensitiveOption);
+    s.replace(regexp, QLatin1String("_"));
 }
 
 #ifdef Q_OS_MAC
@@ -63,10 +64,7 @@ void macosUnsetLaunchctlEnv()
     // Unset Launchd env
     QProcess unsetLaunchdDBusEnv;
     unsetLaunchdDBusEnv.setProgram(QStringLiteral("launchctl"));
-    unsetLaunchdDBusEnv.setArguments({
-        QStringLiteral("unsetenv"),
-        QStringLiteral(KDECONNECT_SESSION_DBUS_LAUNCHD_ENV)
-    });
+    unsetLaunchdDBusEnv.setArguments({QStringLiteral("unsetenv"), QStringLiteral(KDECONNECT_SESSION_DBUS_LAUNCHD_ENV)});
     unsetLaunchdDBusEnv.start();
     unsetLaunchdDBusEnv.waitForFinished();
 }
@@ -74,46 +72,41 @@ void macosUnsetLaunchctlEnv()
 void DBusInstancePrivate::launchDBusDaemon()
 {
     // Kill old dbus daemon
-    if (m_dbusProcess != nullptr) closeDBusDaemon();
+    if (m_dbusProcess != nullptr)
+        closeDBusDaemon();
 
     // Start dbus daemon
     m_dbusProcess = new QProcess();
 
     QString kdeconnectDBusConfiguration;
-    QString dbusDaemonExecutable = QStandardPaths::findExecutable(QStringLiteral("dbus-daemon"), { QCoreApplication::applicationDirPath() });
+    QString dbusDaemonExecutable = QStandardPaths::findExecutable(QStringLiteral("dbus-daemon"), {QCoreApplication::applicationDirPath()});
     if (!dbusDaemonExecutable.isNull()) {
         kdeconnectDBusConfiguration = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("dbus-1/session.conf"));
     } else {
         // macOS Debug env
-        dbusDaemonExecutable = QString::fromLatin1(qgetenv("craftRoot")) + QStringLiteral("/../bin/dbus-daemon");
-        kdeconnectDBusConfiguration = QString::fromLatin1(qgetenv("craftRoot")) + QStringLiteral("/../share/dbus-1/session.conf");
+        dbusDaemonExecutable = QLatin1String(qgetenv("craftRoot")) + QLatin1String("/../bin/dbus-daemon");
+        kdeconnectDBusConfiguration = QLatin1String(qgetenv("craftRoot")) + QLatin1String("/../share/dbus-1/session.conf");
     }
     m_dbusProcess->setProgram(dbusDaemonExecutable);
     m_dbusProcess->setArguments({QStringLiteral("--print-address"),
-        QStringLiteral("--nofork"),
-        QStringLiteral("--config-file=") + kdeconnectDBusConfiguration,
-        QStringLiteral("--address=") + QStringLiteral(KDECONNECT_PRIVATE_DBUS_ADDR)
-    });
+                                 QStringLiteral("--nofork"),
+                                 QStringLiteral("--config-file=") + kdeconnectDBusConfiguration,
+                                 QStringLiteral("--address=") + QStringLiteral(KDECONNECT_PRIVATE_DBUS_ADDR)});
     m_dbusProcess->setWorkingDirectory(QCoreApplication::applicationDirPath());
     m_dbusProcess->setStandardOutputFile(KdeConnectConfig::instance().privateDBusAddressPath());
     m_dbusProcess->setStandardErrorFile(QProcess::nullDevice());
     m_dbusProcess->start();
+    m_dbusProcess->waitForStarted();    // Avoid potential racing condition
 
 #ifdef Q_OS_MAC
     // Set launchctl env
     QString privateDBusAddress = KdeConnectConfig::instance().privateDBusAddress();
     QRegularExpressionMatch path;
-    if (privateDBusAddress.contains(QRegularExpression(
-            QStringLiteral("path=(?<path>/tmp/dbus-[A-Za-z0-9]+)")
-        ), &path)) {
+    if (privateDBusAddress.contains(QRegularExpression(QStringLiteral("path=(?<path>/tmp/dbus-[A-Za-z0-9]+)")), &path)) {
         qCDebug(KDECONNECT_CORE) << "DBus address: " << path.captured(QStringLiteral("path"));
         QProcess setLaunchdDBusEnv;
         setLaunchdDBusEnv.setProgram(QStringLiteral("launchctl"));
-        setLaunchdDBusEnv.setArguments({
-            QStringLiteral("setenv"),
-            QStringLiteral(KDECONNECT_SESSION_DBUS_LAUNCHD_ENV),
-            path.captured(QStringLiteral("path"))
-        });
+        setLaunchdDBusEnv.setArguments({QStringLiteral("setenv"), QStringLiteral(KDECONNECT_SESSION_DBUS_LAUNCHD_ENV), path.captured(QStringLiteral("path"))});
         setLaunchdDBusEnv.start();
         setLaunchdDBusEnv.waitForFinished();
     } else {
@@ -124,8 +117,7 @@ void DBusInstancePrivate::launchDBusDaemon()
 
 void DBusInstancePrivate::closeDBusDaemon()
 {
-    if (m_dbusProcess != nullptr)
-    {
+    if (m_dbusProcess != nullptr) {
         m_dbusProcess->terminate();
         m_dbusProcess->waitForFinished();
         delete m_dbusProcess;
@@ -133,14 +125,17 @@ void DBusInstancePrivate::closeDBusDaemon()
 
         QFile privateDBusAddressFile(KdeConnectConfig::instance().privateDBusAddressPath());
 
-        if (privateDBusAddressFile.exists()) privateDBusAddressFile.resize(0);
+        if (privateDBusAddressFile.exists())
+            privateDBusAddressFile.resize(0);
 
         macosUnsetLaunchctlEnv();
     }
 }
 
 DBusInstancePrivate::DBusInstancePrivate()
-    :m_dbusProcess(nullptr){}
+    : m_dbusProcess(nullptr)
+{
+}
 
 DBusInstancePrivate::~DBusInstancePrivate()
 {
