@@ -5,27 +5,32 @@
  */
 
 #include <QApplication>
-#include <QNetworkAccessManager>
-#include <QTimer>
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QDBusMessage>
-#include <QSessionManager>
-#include <QStandardPaths>
 #include <QIcon>
 #include <QProcess>
+#include <QSessionManager>
+#include <QStandardPaths>
+#include <QTimer>
+
+#ifdef Q_OS_WIN
+#include <Windows.h>
+#endif
 
 #include <KAboutData>
 #include <KDBusService>
-#include <KNotification>
+#include <KIO/Global>
 #include <KLocalizedString>
-#include <KIO/AccessManager>
+#include <KNotification>
+#include <KWindowSystem>
 
 #include <dbushelper.h>
 
+#include "core/backends/pairinghandler.h"
 #include "core/daemon.h"
 #include "core/device.h"
-#include "core/backends/pairinghandler.h"
+#include "core/openconfig.h"
 #include "kdeconnect-version.h"
 #include "kdeconnectd_debug.h"
 
@@ -34,56 +39,66 @@ class DesktopDaemon : public Daemon
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.daemon")
 public:
-    DesktopDaemon(QObject* parent = nullptr)
+    DesktopDaemon(QObject *parent = nullptr)
         : Daemon(parent)
-        , m_nam(nullptr)
     {
-        qApp->setWindowIcon(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.svg")));
+        qApp->setWindowIcon(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.png")));
     }
 
-    void askPairingConfirmation(Device* device) override
+    void askPairingConfirmation(Device *device) override
     {
-        KNotification* notification = new KNotification(QStringLiteral("pairingRequest"), KNotification::NotificationFlag::Persistent);
-        QTimer::singleShot(PairingHandler::pairingTimeoutMsec(), notification, &KNotification::close);
+        KNotification *notification = new KNotification(QStringLiteral("pairingRequest"), KNotification::NotificationFlag::Persistent);
+        QTimer::singleShot(PairingHandler::pairingTimeoutMsec, notification, &KNotification::close);
         notification->setIconName(QStringLiteral("dialog-information"));
         notification->setComponentName(QStringLiteral("kdeconnect"));
         notification->setTitle(QStringLiteral("KDE Connect"));
-        notification->setText(i18n("Pairing request from %1\nKey: %2...", device->name().toHtmlEscaped(), QString::fromUtf8(device->verificationKey().left(8))));
+        notification->setText(
+            i18n("Pairing request from %1\nKey: %2...", device->name().toHtmlEscaped(), QString::fromUtf8(device->verificationKey().left(8))));
+        QString deviceId = device->id();
+        auto openSettings = [deviceId, notification] {
+            OpenConfig oc;
+            oc.setXdgActivationToken(notification->xdgActivationToken());
+            oc.openConfiguration(deviceId);
+        };
+
+#if QT_VERSION_MAJOR == 6
+        KNotificationAction *openSettingsAction = notification->addDefaultAction(i18n("Open"));
+        connect(openSettingsAction, &KNotificationAction::activated, openSettings);
+
+        KNotificationAction *acceptAction = notification->addAction(i18n("Accept"));
+        connect(acceptAction, &KNotificationAction::activated, device, &Device::acceptPairing);
+
+        KNotificationAction *rejectAction = notification->addAction(i18n("Reject"));
+        connect(rejectAction, &KNotificationAction::activated, device, &Device::cancelPairing);
+
+        KNotificationAction *viewKeyAction = notification->addAction(i18n("View key"));
+        connect(viewKeyAction, &KNotificationAction::activated, openSettings);
+#else
         notification->setDefaultAction(i18n("Open"));
         notification->setActions(QStringList() << i18n("Accept") << i18n("Reject") << i18n("View key"));
         connect(notification, &KNotification::action1Activated, device, &Device::acceptPairing);
-        connect(notification, &KNotification::action2Activated, device, &Device::rejectPairing);
-        QString deviceId = device->id();
-        auto openSettings = [this, deviceId] {
-            openConfiguration(deviceId);
-        };
+        connect(notification, &KNotification::action2Activated, device, &Device::cancelPairing);
         connect(notification, &KNotification::action3Activated, openSettings);
-        connect(notification, QOverload<>::of(&KNotification::activated), openSettings);
+        connect(notification, &KNotification::activated, openSettings);
+#endif
+
         notification->sendEvent();
     }
 
-    void reportError(const QString & title, const QString & description) override
+    void reportError(const QString &title, const QString &description) override
     {
         qCWarning(KDECONNECT_DAEMON) << title << ":" << description;
         KNotification::event(KNotification::Error, title, description);
     }
 
-    QNetworkAccessManager* networkAccessManager() override
-    {
-        if (!m_nam) {
-            m_nam = new KIO::Integration::AccessManager(this);
-        }
-        return m_nam;
-    }
-
-    KJobTrackerInterface* jobTracker() override
+    KJobTrackerInterface *jobTracker() override
     {
         return KIO::getJobTracker();
     }
 
     Q_SCRIPTABLE void sendSimpleNotification(const QString &eventId, const QString &title, const QString &text, const QString &iconName) override
     {
-        KNotification* notification = new KNotification(eventId); //KNotification::Persistent
+        KNotification *notification = new KNotification(eventId); // KNotification::Persistent
         notification->setIconName(iconName);
         notification->setComponentName(QStringLiteral("kdeconnect"));
         notification->setTitle(title);
@@ -91,12 +106,10 @@ public:
         notification->sendEvent();
     }
 
-    void quit() override {
+    void quit() override
+    {
         QApplication::quit();
     }
-
-private:
-    QNetworkAccessManager* m_nam;
 };
 
 // Copied from plasma-workspace/libkworkspace/kworkspace.cpp
@@ -106,10 +119,8 @@ static void detectPlatform(int argc, char **argv)
         return;
     }
     for (int i = 0; i < argc; i++) {
-        if (qstrcmp(argv[i], "-platform") == 0 ||
-                qstrcmp(argv[i], "--platform") == 0 ||
-                QByteArray(argv[i]).startsWith("-platform=") ||
-                QByteArray(argv[i]).startsWith("--platform=")) {
+        if (qstrcmp(argv[i], "-platform") == 0 || qstrcmp(argv[i], "--platform") == 0 || QByteArray(argv[i]).startsWith("-platform=")
+            || QByteArray(argv[i]).startsWith("--platform=")) {
             return;
         }
     }
@@ -117,47 +128,62 @@ static void detectPlatform(int argc, char **argv)
     if (sessionType.isEmpty()) {
         return;
     }
-    if (qstrcmp(sessionType, "wayland") == 0) {
+    if (qstrcmp(sessionType.constData(), "wayland") == 0) {
         qputenv("QT_QPA_PLATFORM", "wayland");
-    } else if (qstrcmp(sessionType, "x11") == 0) {
+    } else if (qstrcmp(sessionType.constData(), "x11") == 0) {
         qputenv("QT_QPA_PLATFORM", "xcb");
     }
 }
 
-int main(int argc, char* argv[])
+int main(int argc, char *argv[])
 {
+#ifdef Q_OS_WIN
+    // If ran from a console, redirect the output there
+    if (AttachConsole(ATTACH_PARENT_PROCESS)) {
+        freopen("CONOUT$", "w", stdout);
+        freopen("CONOUT$", "w", stderr);
+    }
+#endif
+
     detectPlatform(argc, argv);
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#if QT_VERSION_MAJOR == 6
+    QGuiApplication::setQuitLockEnabled(false);
+#endif
 
     QApplication app(argc, argv);
-    KAboutData aboutData(
-        QStringLiteral("kdeconnect.daemon"),
-        i18n("KDE Connect Daemon"),
-        QStringLiteral(KDECONNECT_VERSION_STRING),
-        i18n("KDE Connect Daemon"),
-        KAboutLicense::GPL
-    );
+    KAboutData aboutData(QStringLiteral("kdeconnect.daemon"),
+                         i18n("KDE Connect Daemon"),
+                         QStringLiteral(KDECONNECT_VERSION_STRING),
+                         i18n("KDE Connect Daemon"),
+                         KAboutLicense::GPL);
     KAboutData::setApplicationData(aboutData);
     app.setQuitOnLastWindowClosed(false);
 
-#ifdef USE_PRIVATE_DBUS
-    DBusHelper::launchDBusDaemon();
-#endif
-
     QCommandLineParser parser;
     QCommandLineOption replaceOption({QStringLiteral("replace")}, i18n("Replace an existing instance"));
     parser.addOption(replaceOption);
+#ifdef Q_OS_MAC
+    QCommandLineOption macosPrivateDBusOption({QStringLiteral("use-private-dbus")},
+                                              i18n("Launch a private D-Bus daemon with kdeconnectd (macOS test-purpose only)"));
+    parser.addOption(macosPrivateDBusOption);
+#endif
     aboutData.setupCommandLine(&parser);
 
     parser.process(app);
+#ifdef Q_OS_MAC
+    if (parser.isSet(macosPrivateDBusOption)) {
+        DBusHelper::launchDBusDaemon();
+    }
+#endif
     aboutData.processCommandLine(&parser);
     if (parser.isSet(replaceOption)) {
         auto message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"),
-                                                    QStringLiteral("/MainApplication"),
-                                                    QStringLiteral("org.qtproject.Qt.QCoreApplication"),
-                                                    QStringLiteral("quit"));
-        DBusHelper::sessionBus().call(message); //deliberately block until it's done, so we register the name after the app quits
+                                                      QStringLiteral("/MainApplication"),
+                                                      QStringLiteral("org.qtproject.Qt.QCoreApplication"),
+                                                      QStringLiteral("quit"));
+        QDBusConnection::sessionBus().call(message); // deliberately block until it's done, so we register the name after the app quits
     }
 
     KDBusService dbusService(KDBusService::Unique);
@@ -166,7 +192,7 @@ int main(int argc, char* argv[])
 
 #ifdef Q_OS_WIN
     // make sure indicator shows up in the tray whenever daemon is spawned
-    QProcess::startDetached(QStringLiteral("kdeconnect-indicator.exe"));
+    QProcess::startDetached(QStringLiteral("kdeconnect-indicator.exe"), QStringList());
 #endif
 
     // kdeconnectd is autostarted, so disable session management to speed up startup
