@@ -16,7 +16,9 @@ K_PLUGIN_CLASS_WITH_JSON(ClipboardPlugin, "kdeconnect_clipboard.json")
 ClipboardPlugin::ClipboardPlugin(QObject *parent, const QVariantList &args)
     : KdeConnectPlugin(parent, args)
 {
-    connect(ClipboardListener::instance(), &ClipboardListener::clipboardChanged, this, &ClipboardPlugin::propagateClipboard);
+    connect(ClipboardListener::instance(), &ClipboardListener::clipboardChanged, this, &ClipboardPlugin::clipboardChanged);
+    connect(config(), &KdeConnectPluginConfig::configChanged, this, &ClipboardPlugin::configChanged);
+    configChanged();
 }
 
 void ClipboardPlugin::connected()
@@ -24,20 +26,47 @@ void ClipboardPlugin::connected()
     sendConnectPacket();
 }
 
-void ClipboardPlugin::propagateClipboard(const QString &content, ClipboardListener::ClipboardContentType contentType)
+QString ClipboardPlugin::dbusPath() const
 {
-    if (contentType == ClipboardListener::ClipboardContentTypeUnknown) {
-        if (!config()->getBool(QStringLiteral("sendUnknown"), true)) {
-            return;
-        }
-    } else if (contentType == ClipboardListener::ClipboardContentTypePassword) {
-        if (!config()->getBool(QStringLiteral("sendPassword"), true)) {
-            return;
-        }
-    } else {
+    return QLatin1String("/modules/kdeconnect/devices/%1/clipboard").arg(device()->id());
+}
+
+void ClipboardPlugin::clipboardChanged(const QString &content, ClipboardListener::ClipboardContentType contentType)
+{
+    if (!autoShare) {
         return;
     }
 
+    if (contentType == ClipboardListener::ClipboardContentTypePassword) {
+        if (!sharePasswords) {
+            return;
+        }
+    }
+
+    sendClipboard(content);
+}
+
+void ClipboardPlugin::configChanged()
+{
+    autoShare = config()->getBool(QStringLiteral("autoShare"), config()->getBool(QStringLiteral("sendUnknown"), true));
+    sharePasswords = config()->getBool(QStringLiteral("sendPassword"), true);
+    Q_EMIT autoShareDisabledChanged(isAutoShareDisabled());
+}
+
+bool ClipboardPlugin::isAutoShareDisabled()
+{
+    // Return true also if autoShare is enabled but disabled for passwords
+    return !autoShare || !sharePasswords;
+}
+
+void ClipboardPlugin::sendClipboard()
+{
+    QString content = ClipboardListener::instance()->currentContent();
+    sendClipboard(content);
+}
+
+void ClipboardPlugin::sendClipboard(const QString &content)
+{
     NetworkPacket np(PACKET_TYPE_CLIPBOARD, {{QStringLiteral("content"), content}});
     sendPacket(np);
 }
@@ -50,23 +79,22 @@ void ClipboardPlugin::sendConnectPacket()
     sendPacket(np);
 }
 
-bool ClipboardPlugin::receivePacket(const NetworkPacket &np)
+void ClipboardPlugin::receivePacket(const NetworkPacket &np)
 {
     QString content = np.get<QString>(QStringLiteral("content"));
     if (np.type() == PACKET_TYPE_CLIPBOARD) {
         ClipboardListener::instance()->setText(content);
-        return true;
     } else if (np.type() == PACKET_TYPE_CLIPBOARD_CONNECT) {
         qint64 packetTime = np.get<qint64>(QStringLiteral("timestamp"));
         // If the packetTime is 0, it means the timestamp is unknown (so do nothing).
         if (packetTime == 0 || packetTime < ClipboardListener::instance()->updateTimestamp()) {
-            return false;
+            qCWarning(KDECONNECT_PLUGIN_CLIPBOARD) << "Ignoring clipboard without timestamp";
+            return;
         }
 
         ClipboardListener::instance()->setText(content);
-        return true;
     }
-    return false;
 }
 
 #include "clipboardplugin.moc"
+#include "moc_clipboardplugin.cpp"
