@@ -14,15 +14,11 @@
 #include <QJsonArray>
 #include <QProcess>
 #include <QScreen>
+#include <QStandardPaths>
 
 K_PLUGIN_CLASS_WITH_JSON(VirtualMonitorPlugin, "kdeconnect_virtualmonitor.json")
 #define QS QLatin1String
 
-VirtualMonitorPlugin::VirtualMonitorPlugin(QObject *parent, const QVariantList &args)
-    : KdeConnectPlugin(parent, args)
-{
-}
-
 VirtualMonitorPlugin::~VirtualMonitorPlugin()
 {
     stop();
@@ -58,7 +54,7 @@ void VirtualMonitorPlugin::connected()
     sendPacket(np);
 }
 
-bool VirtualMonitorPlugin::receivePacket(const NetworkPacket &received)
+void VirtualMonitorPlugin::receivePacket(const NetworkPacket &received)
 {
     if (received.type() == PACKET_TYPE_VIRTUALMONITOR_REQUEST && received.has(QS("url"))) {
         QUrl url(received.get<QString>(QS("url")));
@@ -75,7 +71,6 @@ bool VirtualMonitorPlugin::receivePacket(const NetworkPacket &received)
             stop();
         }
     }
-    return true;
 }
 
 QString VirtualMonitorPlugin::dbusPath() const
@@ -84,7 +79,7 @@ QString VirtualMonitorPlugin::dbusPath() const
     if (QStandardPaths::findExecutable(QS("krfb-virtualmonitor")).isEmpty())
         return {};
 
-    return QS("/modules/kdeconnect/devices/") + device()->id() + QS("/virtualmonitor");
+    return QLatin1String("/modules/kdeconnect/devices/%1/virtualmonitor").arg(device()->id());
 }
 
 bool VirtualMonitorPlugin::requestVirtualMonitor()
@@ -114,7 +109,7 @@ bool VirtualMonitorPlugin::requestVirtualMonitor()
                              uuid.toString(),
                              QS("--port"),
                              port});
-    connect(m_process, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, [this](int exitCode, QProcess::ExitStatus exitStatus) {
+    connect(m_process, &QProcess::finished, this, [this](int exitCode, QProcess::ExitStatus exitStatus) {
         qCWarning(KDECONNECT_PLUGIN_VIRTUALMONITOR) << "virtual display finished with" << device()->name() << m_process->readAllStandardError();
 
         if (m_retries < 5 && (exitCode == 1 || exitStatus == QProcess::CrashExit)) {
@@ -144,4 +139,5 @@ bool VirtualMonitorPlugin::requestVirtualMonitor()
     return true;
 }
 
+#include "moc_virtualmonitorplugin.cpp"
 #include "virtualmonitorplugin.moc"
